This is the mail archive of the gdb-cvs@sourceware.org mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[binutils-gdb] Handle 64-bit Solaris/x86 ld.so.1


https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=7307a73aed246eaccec9277b11e045f974322796

commit 7307a73aed246eaccec9277b11e045f974322796
Author: Rainer Orth <ro@CeBiTec.Uni-Bielefeld.DE>
Date:   Wed Sep 19 11:29:19 2018 +0200

    Handle 64-bit Solaris/x86 ld.so.1
    
    The next patch from the solaris-userland github repo
    
    	https://github.com/oracle/solaris-userland/tree/master/components/gdb/patches
    
    (007-solib-svr4.patch) is equally trivial, creating partity between
    Solaris/SPARC and x86.
    
    Tested on amd64-pc-solaris2.11.
    
    2018-09-19  George Vasick <george.vasick@oracle.com>
    
    	* solib-svr4.c (svr4_same_1): Also handle amd64 ld.so.1.

Diff:
---
 gdb/ChangeLog    | 4 ++++
 gdb/solib-svr4.c | 6 +++++-
 2 files changed, 9 insertions(+), 1 deletion(-)

diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 0fe15ef..0c75340 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,7 @@
+2018-09-19  George Vasick <george.vasick@oracle.com>
+
+	* solib-svr4.c (svr4_same_1): Also handle amd64 ld.so.1.
+
 2018-09-19  Stefan Teleman <stefan.teleman@oracle.com>
 	    April Chin <april.chin@oracle.com>
 	    Rainer Orth  <ro@CeBiTec.Uni-Bielefeld.DE>
diff --git a/gdb/solib-svr4.c b/gdb/solib-svr4.c
index bfef217..29df63f 100644
--- a/gdb/solib-svr4.c
+++ b/gdb/solib-svr4.c
@@ -153,8 +153,12 @@ svr4_same_1 (const char *gdb_so_name, const char *inferior_so_name)
       && strcmp (inferior_so_name, "/lib/ld.so.1") == 0)
     return 1;
 
   /* Similarly, we observed the same issue with sparc64, but with
      different locations.  */
+  if (strcmp (gdb_so_name, "/usr/lib/amd64/ld.so.1") == 0
+      && strcmp (inferior_so_name, "/lib/amd64/ld.so.1") == 0)
+    return 1;
+
   if (strcmp (gdb_so_name, "/usr/lib/sparcv9/ld.so.1") == 0
       && strcmp (inferior_so_name, "/lib/sparcv9/ld.so.1") == 0)
     return 1;
@@ -153,8 +153,12 @@ svr4_same_1 (const char *gdb_so_name, const char *inferior_so_name)
     return 1;
 
-  /* Similarly, we observed the same issue with sparc64, but with
+  /* Similarly, we observed the same issue with amd64 and sparcv9, but with
      different locations.  */


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]